@@ -9,6 +9,7 @@ try:
 except: pass
 
 import asyncio
+from aiohttp.client_exceptions import ServerDisconnectedError
 
 
 class BaseBot:
@@ -81,7 +82,7 @@ class BaseBot:
 
         for cb_func in self._cb_funcs:
             if cb_func[0](callback_query):
-                cb_func[1](callback_query)
+                await cb_func[1](callback_query)
 
 
     def _process_response(self, json_data: dict, cls):
@@ -107,11 +108,15 @@ class BaseBot:
                 print(f'Update attribute {update.dict()} not support')
         
 
-    async def polling(self):
+    async def polling(self, tg_disconnected_delay: float = 2.0):
         async with self._api.session:
             while True:
-                json_data = await self._api.get_updates(timeout=60, offset=self._update_offset)
-                await self._process_updates_json(json_data)
+                try:
+                    json_data = await self._api.get_updates(timeout=60, offset=self._update_offset)
+                    await self._process_updates_json(json_data)
+                except ServerDisconnectedError as e:
+                    print(f'Telegram server disconected: {e}')
+                    await asyncio.sleep(tg_disconnected_delay)
 
 
     async def __call__(self, scope, receive, send):
